/*
 * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.TimeZoneNamesBundle;

public class TimeZoneNames_zh_Hant_HK extends TimeZoneNamesBundle {
    @Override
    protected final Object[][] getContents() {
        final String[] Gulf = new String[] {
               "\u6ce2\u65af\u7063\u6d77\u57df\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Cocos = new String[] {
               "\u53ef\u53ef\u65af\u7fa4\u5cf6\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] India = new String[] {
               "\u5370\u5ea6\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Nauru = new String[] {
               "\u7459\u9b6f\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tonga = new String[] {
               "\u6e6f\u52a0\u6a19\u6e96\u6642\u9593",
               "",
               "\u6e6f\u52a0\u590f\u4ee4\u6642\u9593",
               "",
               "\u6e6f\u52a0\u6642\u9593",
               "",
            };
        final String[] Guyana = new String[] {
               "\u572d\u4e9e\u90a3\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Kosrae = new String[] {
               "\u79d1\u65af\u96f7\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Tuvalu = new String[] {
               "\u5716\u74e6\u76e7\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Ecuador = new String[] {
               "\u5384\u74dc\u591a\u723e\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Georgia = new String[] {
               "\u683c\u9b6f\u5409\u4e9e\u6a19\u6e96\u6642\u9593",
               "",
               "\u683c\u9b6f\u5409\u4e9e\u590f\u4ee4\u6642\u9593",
               "",
               "\u683c\u9b6f\u5409\u4e9e\u6642\u9593",
               "",
            };
        final String[] Irkutsk = new String[] {
               "\u4f0a\u723e\u5eab\u8328\u514b\u6a19\u6e96\u6642\u9593",
               "",
               "\u4f0a\u723e\u5eab\u8328\u514b\u590f\u4ee4\u6642\u9593",
               "",
               "\u4f0a\u723e\u5eab\u8328\u514b\u6642\u9593",
               "",
            };
        final String[] Noronha = new String[] {
               "\u8cbb\u723e\u5357\u591a\u8fea\u8afe\u7f85\u5c3c\u4e9e\u6a19\u6e96\u6642\u9593",
               "",
               "\u8cbb\u723e\u5357\u591a\u8fea\u8afe\u7f85\u5c3c\u4e9e\u590f\u4ee4\u6642\u9593",
               "",
               "\u8cbb\u723e\u5357\u591a\u8fea\u8afe\u7f85\u5c3c\u4e9e\u6642\u9593",
               "",
            };
        final String[] Solomon = new String[] {
               "\u6240\u7f85\u9580\u7fa4\u5cf6\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Vanuatu = new String[] {
               "\u74e6\u52aa\u963f\u5716\u6a19\u6e96\u6642\u9593",
               "",
               "\u74e6\u52aa\u963f\u5716\u590f\u4ee4\u6642\u9593",
               "",
               "\u74e6\u52aa\u963f\u5716\u6642\u9593",
               "",
            };
        final String[] Yakutsk = new String[] {
               "\u96c5\u5eab\u8328\u514b\u6a19\u6e96\u6642\u9593",
               "",
               "\u96c5\u5eab\u8328\u514b\u590f\u4ee4\u6642\u9593",
               "",
               "\u96c5\u5eab\u8328\u514b\u6642\u9593",
               "",
            };
        final String[] Maldives = new String[] {
               "\u99ac\u723e\u4ee3\u592b\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Pitcairn = new String[] {
               "\u76ae\u7279\u5eb7\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Suriname = new String[] {
               "\u8607\u91cc\u5357\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Galapagos = new String[] {
               "\u52a0\u62c9\u5e15\u6208\u7fa4\u5cf6\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Marquesas = new String[] {
               "\u99ac\u514b\u85a9\u65af\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Mauritius = new String[] {
               "\u6bdb\u91cc\u88d8\u65af\u6a19\u6e96\u6642\u9593",
               "",
               "\u6bdb\u91cc\u88d8\u65af\u590f\u4ee4\u6642\u9593",
               "",
               "\u6bdb\u91cc\u88d8\u65af\u6642\u9593",
               "",
            };
        final String[] Singapore = new String[] {
               "\u65b0\u52a0\u5761\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Azerbaijan = new String[] {
               "\u4e9e\u585e\u62dc\u7586\u6a19\u6e96\u6642\u9593",
               "",
               "\u4e9e\u585e\u62dc\u7586\u590f\u4ee4\u6642\u9593",
               "",
               "\u4e9e\u585e\u62dc\u7586\u6642\u9593",
               "",
            };
        final String[] Cape_Verde = new String[] {
               "\u4f5b\u5f97\u89d2\u6a19\u6e96\u6642\u9593",
               "",
               "\u4f5b\u5f97\u89d2\u590f\u4ee4\u6642\u9593",
               "",
               "\u4f5b\u5f97\u89d2\u6642\u9593",
               "",
            };
        final String[] EMPTY_ZONE = new String[] {
               "",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Seychelles = new String[] {
               "\u585e\u820c\u723e\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] New_Caledonia = new String[] {
               "\u65b0\u5580\u91cc\u591a\u5c3c\u4e9e\u6a19\u6e96\u6642\u9593",
               "",
               "\u65b0\u5580\u91cc\u591a\u5c3c\u4e9e\u590f\u4ee4\u6642\u9593",
               "",
               "\u65b0\u5580\u91cc\u591a\u5c3c\u4e9e\u6642\u9593",
               "",
            };
        final String[] DumontDUrville = new String[] {
               "\u8fea\u8499\u8fea\u7dad\u723e\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] Africa_Southern = new String[] {
               "\u5357\u975e\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final String[] America_Central = new String[] {
               "\u5317\u7f8e\u4e2d\u90e8\u6a19\u6e96\u6642\u9593",
               "CST",
               "\u5317\u7f8e\u4e2d\u90e8\u590f\u4ee4\u6642\u9593",
               "CDT",
               "\u5317\u7f8e\u4e2d\u90e8\u6642\u9593",
               "CT",
            };
        final String[] America_Eastern = new String[] {
               "\u5317\u7f8e\u6771\u90e8\u6a19\u6e96\u6642\u9593",
               "EST",
               "\u5317\u7f8e\u6771\u90e8\u590f\u4ee4\u6642\u9593",
               "EDT",
               "\u5317\u7f8e\u6771\u90e8\u6642\u9593",
               "ET",
            };
        final String[] America_Pacific = new String[] {
               "\u5317\u7f8e\u592a\u5e73\u6d0b\u6a19\u6e96\u6642\u9593",
               "PST",
               "\u5317\u7f8e\u592a\u5e73\u6d0b\u590f\u4ee4\u6642\u9593",
               "PDT",
               "\u5317\u7f8e\u592a\u5e73\u6d0b\u6642\u9593",
               "PT",
            };
        final String[] America_Mountain = new String[] {
               "\u5317\u7f8e\u5c71\u5340\u6a19\u6e96\u6642\u9593",
               "MST",
               "\u5317\u7f8e\u5c71\u5340\u590f\u4ee4\u6642\u9593",
               "MDT",
               "\u5317\u7f8e\u5c71\u5340\u6642\u9593",
               "MT",
            };
        final String[] Papua_New_Guinea = new String[] {
               "\u5df4\u5e03\u4e9e\u65b0\u757f\u5167\u4e9e\u6642\u9593",
               "",
               "",
               "",
               "",
               "",
            };
        final Object[][] data = new Object[][] {
            { "America/Los_Angeles", America_Pacific },
            { "America/Denver", America_Mountain },
            { "America/Phoenix", America_Mountain },
            { "America/Chicago", America_Central },
            { "America/New_York", America_Eastern },
            { "America/Indianapolis", America_Eastern },
            { "UTC", EMPTY_ZONE },
            { "CST", America_Central },
            { "PNT", America_Mountain },
            { "PST", America_Pacific },
            { "SST", Solomon },
            { "CST6CDT", America_Central },
            { "EST5EDT", America_Eastern },
            { "MST7MDT", America_Mountain },
            { "PST8PDT", America_Pacific },
            { "Asia/Baku", Azerbaijan },
            { "Asia/Chita", Yakutsk },
            { "Asia/Dubai", Gulf },
            { "Asia/Muscat", Gulf },
            { "Indian/Mahe", Seychelles },
            { "Asia/Colombo", India },
            { "Asia/Irkutsk", Irkutsk },
            { "Asia/Tbilisi", Georgia },
            { "Asia/Yakutsk", Yakutsk },
            { "Indian/Cocos", Cocos },
            { "SystemV/CST6", America_Central },
            { "SystemV/EST5", America_Eastern },
            { "SystemV/MST7", America_Mountain },
            { "SystemV/PST8", Pitcairn },
            { "Africa/Maseru", Africa_Southern },
            { "America/Boise", America_Mountain },
            { "Asia/Calcutta", India },
            { "Asia/Khandyga", Yakutsk },
            { "Pacific/Efate", Vanuatu },
            { "Pacific/Nauru", Nauru },
            { "Africa/Mbabane", Africa_Southern },
            { "America/Belize", America_Central },
            { "America/Cancun", America_Eastern },
            { "America/Cayman", America_Eastern },
            { "America/Guyana", Guyana },
            { "America/Inuvik", America_Mountain },
            { "America/Merida", America_Central },
            { "America/Nassau", America_Eastern },
            { "America/Panama", America_Eastern },
            { "America/Regina", America_Central },
            { "Asia/Singapore", Singapore },
            { "Pacific/Kosrae", Kosrae },
            { "Pacific/Noumea", New_Caledonia },
            { "America/Creston", America_Mountain },
            { "America/Detroit", America_Eastern },
            { "America/Iqaluit", America_Eastern },
            { "America/Jamaica", America_Eastern },
            { "America/Managua", America_Central },
            { "America/Nipigon", America_Eastern },
            { "America/Noronha", Noronha },
            { "America/Ojinaga", America_Central },
            { "America/Tijuana", America_Pacific },
            { "America/Toronto", America_Eastern },
            { "Indian/Maldives", Maldives },
            { "SystemV/CST6CDT", America_Central },
            { "SystemV/EST5EDT", America_Eastern },
            { "SystemV/MST7MDT", America_Mountain },
            { "SystemV/PST8PDT", America_Pacific },
            { "America/Edmonton", America_Mountain },
            { "America/Montreal", America_Eastern },
            { "America/Resolute", America_Central },
            { "America/Shiprock", America_Mountain },
            { "America/Winnipeg", America_Central },
            { "Indian/Mauritius", Mauritius },
            { "Pacific/Funafuti", Tuvalu },
            { "Pacific/Pitcairn", Pitcairn },
            { "America/Chihuahua", America_Central },
            { "America/Guatemala", America_Central },
            { "America/Guayaquil", Ecuador },
            { "America/Matamoros", America_Central },
            { "America/Menominee", America_Central },
            { "America/Monterrey", America_Central },
            { "America/Vancouver", America_Pacific },
            { "Pacific/Galapagos", Galapagos },
            { "Pacific/Marquesas", Marquesas },
            { "Pacific/Tongatapu", Tonga },
            { "America/Costa_Rica", America_Central },
            { "America/Grand_Turk", America_Eastern },
            { "America/Louisville", America_Eastern },
            { "America/Paramaribo", Suriname },
            { "Africa/Johannesburg", Africa_Southern },
            { "America/El_Salvador", America_Central },
            { "America/Fort_Nelson", America_Mountain },
            { "America/Mexico_City", America_Central },
            { "America/Pangnirtung", America_Eastern },
            { "America/Rainy_River", America_Central },
            { "America/Tegucigalpa", America_Central },
            { "America/Thunder_Bay", America_Eastern },
            { "America/Yellowknife", America_Mountain },
            { "Atlantic/Cape_Verde", Cape_Verde },
            { "Pacific/Guadalcanal", Solomon },
            { "America/Dawson_Creek", America_Mountain },
            { "America/Indiana/Knox", America_Central },
            { "America/Rankin_Inlet", America_Central },
            { "Pacific/Port_Moresby", Papua_New_Guinea },
            { "America/Cambridge_Bay", America_Mountain },
            { "America/Coral_Harbour", America_Eastern },
            { "America/Indiana/Vevay", America_Eastern },
            { "America/Swift_Current", America_Central },
            { "America/Bahia_Banderas", America_Central },
            { "America/Port-au-Prince", America_Eastern },
            { "America/Indiana/Marengo", America_Eastern },
            { "America/Indiana/Winamac", America_Eastern },
            { "America/Indiana/Tell_City", America_Central },
            { "America/Indiana/Vincennes", America_Eastern },
            { "Antarctica/DumontDUrville", DumontDUrville },
            { "timezone.excity.Asia/Gaza", "\u52a0\u6c99" },
            { "America/Indiana/Petersburg", America_Eastern },
            { "timezone.excity.Asia/Qatar", "\u5361\u5854\u723e" },
            { "America/Kentucky/Monticello", America_Eastern },
            { "America/North_Dakota/Beulah", America_Central },
            { "America/North_Dakota/Center", America_Central },
            { "timezone.excity.Asia/Anadyr", "\u963f\u7d0d\u5fb7\u723e" },
            { "timezone.excity.Asia/Hebron", "\u5e0c\u4f2f\u4f96" },
            { "timezone.excity.Asia/Muscat", "\u99ac\u65af\u5580\u7279" },
            { "timezone.excity.Asia/Riyadh", "\u5229\u96c5\u5f97" },
            { "timezone.excity.Africa/Lagos", "\u62c9\u5404\u65af" },
            { "timezone.excity.America/Adak", "\u57c3\u9054\u514b" },
            { "timezone.excity.Asia/Bishkek", "\u6bd4\u65af\u51f1\u514b" },
            { "timezone.excity.Asia/Colombo", "\u79d1\u502b\u5761" },
            { "timezone.excity.Asia/Irkutsk", "\u4f0a\u723e\u5eab\u8328\u514b" },
            { "timezone.excity.Asia/Karachi", "\u5361\u62c9\u5947" },
            { "timezone.excity.Asia/Nicosia", "\u5c3c\u79d1\u897f\u4e9e" },
            { "timezone.excity.Asia/Yakutsk", "\u96c5\u5eab\u8328\u514b" },
            { "timezone.excity.Asia/Yerevan", "\u57c3\u91cc\u6e29" },
            { "timezone.excity.Europe/Malta", "\u99ac\u8033\u4ed6" },
            { "timezone.excity.Europe/Vaduz", "\u83ef\u675c\u8332" },
            { "timezone.excity.Indian/Cocos", "\u53ef\u53ef\u65af\u7fa4\u5cf6" },
            { "timezone.excity.Pacific/Wake", "\u5a01\u514b\u5cf6" },
            { "timezone.excity.Africa/Asmera", "\u963f\u65af\u99ac\u62c9" },
            { "timezone.excity.Africa/Bangui", "\u73ed\u57fa" },
            { "timezone.excity.Africa/Luanda", "\u76e7\u5b89\u9054" },
            { "timezone.excity.Africa/Lusaka", "\u76e7\u85a9\u5361" },
            { "timezone.excity.Africa/Maseru", "\u99ac\u585e\u9b6f" },
            { "timezone.excity.America/Aruba", "\u963f\u9b6f\u5df4" },
            { "timezone.excity.America/Bahia", "\u5df4\u5e0c\u96c5" },
            { "timezone.excity.America/Boise", "\u535a\u4f0a\u897f" },
            { "timezone.excity.America/Thule", "\u5716\u52d2" },
            { "timezone.excity.Asia/Ashgabat", "\u963f\u4ec0\u54c8\u5df4\u5fb7" },
            { "timezone.excity.Asia/Dushanbe", "\u675c\u5c1a\u5225" },
            { "timezone.excity.Asia/Jayapura", "\u67e5\u96c5\u666e\u62c9" },
            { "timezone.excity.Asia/Makassar", "\u932b\u6c5f" },
            { "timezone.excity.Europe/Skopje", "\u65af\u79d1\u666e\u91cc" },
            { "timezone.excity.Europe/Zagreb", "\u85a9\u683c\u52d2\u5e03" },
            { "timezone.excity.Indian/Chagos", "\u67e5\u6208\u65af\u7fa4\u5cf6" },
            { "timezone.excity.Indian/Comoro", "\u79d1\u6469\u7f85" },
            { "timezone.excity.Pacific/Nauru", "\u7459\u9b6f" },
            { "America/North_Dakota/New_Salem", America_Central },
            { "timezone.excity.Africa/Abidjan", "\u963f\u6bd4\u8d0a" },
            { "timezone.excity.Africa/Conakry", "\u79d1\u7d0d\u514b\u91cc" },
            { "timezone.excity.Africa/Nairobi", "\u5167\u7f85\u7562" },
            { "timezone.excity.America/Belize", "\u4f2f\u5229\u8332" },
            { "timezone.excity.America/Cuiaba", "\u5eab\u4e9e\u5df4" },
            { "timezone.excity.America/Guyana", "\u572d\u4e9e\u90a3" },
            { "timezone.excity.America/Havana", "\u590f\u7063\u62ff" },
            { "timezone.excity.America/Inuvik", "\u4f0a\u52aa\u7dad\u514b" },
            { "timezone.excity.America/Maceio", "\u99ac\u585e\u7d04" },
            { "timezone.excity.America/Nassau", "\u62ff\u9a37" },
            { "timezone.excity.America/Recife", "\u7d2f\u897f\u8153" },
            { "timezone.excity.Indian/Mayotte", "\u99ac\u7d04\u7279" },
            { "timezone.excity.Indian/Reunion", "\u7559\u5c3c\u65fa" },
            { "timezone.excity.Pacific/Kosrae", "\u79d1\u65af\u96f7" },
            { "timezone.excity.Pacific/Majuro", "\u99ac\u4e45\u7f85" },
            { "timezone.excity.Pacific/Noumea", "\u52aa\u7f8e\u963f" },
            { "timezone.excity.Africa/Djibouti", "\u5409\u5e03\u63d0" },
            { "timezone.excity.Africa/Kinshasa", "\u91d1\u6c99\u85a9" },
            { "timezone.excity.Africa/Windhoek", "\u6eab\u7279\u548c\u514b" },
            { "timezone.excity.America/Antigua", "\u5b89\u63d0\u74dc" },
            { "timezone.excity.America/Caracas", "\u52a0\u62c9\u52a0\u65af" },
            { "timezone.excity.America/Cayenne", "\u5361\u5bb4" },
            { "timezone.excity.America/Cordoba", "\u79d1\u723e\u591a\u74e6" },
            { "timezone.excity.America/Grenada", "\u683c\u6797\u7d0d\u9054" },
            { "timezone.excity.America/Halifax", "\u54c8\u5229\u6cd5\u514b\u65af" },
            { "timezone.excity.America/Managua", "\u99ac\u90a3\u74dc" },
            { "timezone.excity.America/Nipigon", "\u5c3c\u76ae\u8ca2" },
            { "timezone.excity.America/Noronha", "\u8afe\u7f85\u5c3c\u4e9e" },
            { "timezone.excity.America/Tijuana", "\u8482\u83ef\u7d0d" },
            { "timezone.excity.America/Yakutat", "\u4e9e\u5eab\u5854\u7279" },
            { "timezone.excity.Atlantic/Canary", "\u52a0\u90a3\u5229" },
            { "timezone.excity.Australia/Perth", "\u73c0\u65af" },
            { "timezone.excity.Europe/Belgrade", "\u8c9d\u723e\u683c\u840a\u5fb7" },
            { "timezone.excity.Europe/Chisinau", "\u57fa\u5e0c\u8a25\u70cf" },
            { "timezone.excity.Europe/Guernsey", "\u6839\u897f\u5cf6" },
            { "timezone.excity.Europe/Sarajevo", "\u85a9\u62c9\u71b1\u7aa9" },
            { "timezone.excity.Europe/Uzhgorod", "\u70cf\u65e5\u54e5\u7f85\u5fb7" },
            { "timezone.excity.Indian/Maldives", "\u99ac\u723e\u4ee3\u592b" },
            { "timezone.excity.Pacific/Chatham", "\u67e5\u5854\u59c6" },
            { "timezone.excity.Pacific/Fakaofo", "\u6cd5\u8003\u798f\u74b0\u7901" },
            { "timezone.excity.Pacific/Gambier", "\u7518\u6bd4\u723e" },
            { "timezone.excity.Africa/Mogadishu", "\u6469\u52a0\u8fea\u6c99" },
            { "timezone.excity.America/Anguilla", "\u5b89\u572d\u62c9" },
            { "timezone.excity.America/Asuncion", "\u963f\u677e\u68ee" },
            { "timezone.excity.America/Barbados", "\u5df4\u5df4\u591a\u65af" },
            { "timezone.excity.America/Edmonton", "\u611b\u6c11\u9813" },
            { "timezone.excity.America/Miquelon", "\u5bc6\u514b\u9686" },
            { "timezone.excity.America/Santiago", "\u8056\u5730\u4e9e\u54e5" },
            { "timezone.excity.America/St_Johns", "\u8056\u7d04\u7ff0\u65af" },
            { "timezone.excity.America/St_Lucia", "\u8056\u76e7\u897f\u4e9e" },
            { "timezone.excity.Antarctica/Casey", "\u51f1\u897f\u7ad9" },
            { "timezone.excity.Antarctica/Davis", "\u6234\u7dad\u65af\u7ad9" },
            { "timezone.excity.Antarctica/Syowa", "\u662d\u548c\u7ad9" },
            { "timezone.excity.Antarctica/Troll", "\u7279\u7f85\u723e\u7ad9" },
            { "timezone.excity.Atlantic/Madeira", "\u99ac\u5fb7\u62c9\u5cf6" },
            { "timezone.excity.Atlantic/Stanley", "\u53f2\u4e39\u5229" },
            { "timezone.excity.Australia/Currie", "\u5361\u91cc" },
            { "timezone.excity.Australia/Hobart", "\u8377\u4f2f\u7279" },
            { "timezone.excity.Australia/Sydney", "\u6089\u5c3c" },
            { "timezone.excity.Europe/Ljubljana", "\u76e7\u5e03\u723e\u96c5\u90a3" },
            { "timezone.excity.Europe/Podgorica", "\u6ce2\u5fb7\u6208\u91cc\u5bdf" },
            { "timezone.excity.Indian/Kerguelen", "\u51f1\u723e\u84cb\u6717\u7fa4\u5cf6" },
            { "timezone.excity.Indian/Mauritius", "\u6bdb\u91cc\u88d8\u65af" },
            { "timezone.excity.Pacific/Johnston", "\u7d04\u7ff0\u65af\u9813\u74b0\u7901" },
            { "timezone.excity.Pacific/Pitcairn", "\u76ae\u7279\u5eb7\u7fa4\u5cf6" },
            { "timezone.excity.Africa/Libreville", "\u5229\u5e03\u7dad" },
            { "timezone.excity.Africa/Nouakchott", "\u52aa\u74e6\u514b\u8096\u7279" },
            { "timezone.excity.America/Anchorage", "\u5b89\u514b\u96f7\u5947" },
            { "timezone.excity.America/Araguaina", "\u963f\u62c9\u74dc\u4f0a\u7d0d" },
            { "timezone.excity.America/Boa_Vista", "\u535a\u963f\u7dad\u65af\u5854" },
            { "timezone.excity.America/Chihuahua", "\u829d\u5a03\u5a03" },
            { "timezone.excity.America/Fortaleza", "\u798f\u5854\u840a\u85a9" },
            { "timezone.excity.America/Glace_Bay", "\u683c\u840a\u65af\u7063" },
            { "timezone.excity.America/Guatemala", "\u5371\u5730\u99ac\u62c9" },
            { "timezone.excity.America/Menominee", "\u6885\u8afe\u7c73\u5c3c" },
            { "timezone.excity.America/Monterrey", "\u8499\u7279\u96f7" },
            { "timezone.excity.Antarctica/Mawson", "\u83ab\u68ee\u7ad9" },
            { "timezone.excity.Antarctica/Palmer", "\u5e15\u723e\u9ed8" },
            { "timezone.excity.Europe/Bratislava", "\u4f2f\u62c9\u7b2c\u65af\u62c9\u74e6" },
            { "timezone.excity.Pacific/Enderbury", "\u6069\u5fb7\u4f2f\u91cc\u5cf6" },
            { "timezone.excity.Pacific/Kwajalein", "\u74dc\u52a0\u6797\u74b0\u7901" },
            { "timezone.excity.Pacific/Marquesas", "\u99ac\u514b\u85a9\u65af\u7fa4\u5cf6" },
            { "timezone.excity.Pacific/Pago_Pago", "\u5e15\u679c\u5e15\u679c" },
            { "timezone.excity.Pacific/Tongatapu", "\u6e6f\u52a0\u5854\u5e03\u5cf6" },
            { "timezone.excity.America/Costa_Rica", "\u54e5\u65af\u9054\u9ece\u52a0" },
            { "timezone.excity.America/Guadeloupe", "\u74dc\u5fb7\u7f85\u666e" },
            { "timezone.excity.America/Louisville", "\u8def\u6613\u7dad\u723e" },
            { "timezone.excity.America/Martinique", "\u99ac\u63d0\u5c3c\u514b" },
            { "timezone.excity.America/Montevideo", "\u8499\u5f97\u7dad\u7684\u4e9e" },
            { "timezone.excity.America/Montserrat", "\u8499\u585e\u62c9\u7279\u5cf6" },
            { "timezone.excity.America/Rio_Branco", "\u91cc\u7d04\u5e03\u862d\u79d1" },
            { "timezone.excity.America/St_Vincent", "\u8056\u6587\u68ee\u7279" },
            { "timezone.excity.America/Whitehorse", "\u767d\u99ac\u5e02" },
            { "timezone.excity.Antarctica/McMurdo", "\u9ea5\u514b\u9ed8\u591a\u7ad9" },
            { "timezone.excity.Antarctica/Rothera", "\u7f85\u745f\u62c9\u7ad9" },
            { "timezone.excity.Asia/Yekaterinburg", "\u8449\u5361\u6377\u7433\u5821" },
            { "timezone.excity.Atlantic/Reykjavik", "\u96f7\u514b\u96c5\u672a\u514b" },
            { "timezone.excity.Australia/Adelaide", "\u963f\u5fb7\u840a\u5fb7" },
            { "timezone.excity.Australia/Brisbane", "\u5e03\u91cc\u65af\u672c" },
            { "timezone.excity.Europe/Isle_of_Man", "\u99ac\u6069\u5cf6" },
            { "timezone.excity.Africa/Johannesburg", "\u7d04\u7ff0\u5167\u65af\u5821" },
            { "timezone.excity.America/Mexico_City", "\u58a8\u897f\u54e5\u57ce" },
            { "timezone.excity.America/Porto_Velho", "\u97cb\u67f3\u6e2f" },
            { "timezone.excity.America/Tegucigalpa", "\u7279\u53e4\u897f\u52a0\u723e\u5df4" },
            { "timezone.excity.America/Thunder_Bay", "\u96f7\u7063" },
            { "timezone.excity.America/Yellowknife", "\u9ec3\u5200\u93ae" },
            { "timezone.excity.Arctic/Longyearbyen", "\u6717\u4f0a\u723e\u57ce" },
            { "timezone.excity.Atlantic/Cape_Verde", "\u4f5b\u5f97\u89d2" },
            { "timezone.excity.Indian/Antananarivo", "\u5b89\u5854\u90a3\u90a3\u5229\u4f5b" },
            { "timezone.excity.Pacific/Guadalcanal", "\u74dc\u9054\u723e\u5361\u7d0d\u723e\u5cf6" },
            { "timezone.excity.Africa/Dar_es_Salaam", "\u9054\u7d2f\u65af\u85a9\u62c9\u59c6" },
            { "timezone.excity.America/Campo_Grande", "\u5927\u574e\u666e" },
            { "timezone.excity.America/Dawson_Creek", "\u9053\u68ee\u7063" },
            { "timezone.excity.America/Indiana/Knox", "\u5370\u7b2c\u5b89\u7d0d\u5dde\u8afe\u514b\u65af" },
            { "timezone.excity.America/Indianapolis", "\u5370\u7b2c\u5b89\u7d0d\u6ce2\u5229\u65af" },
            { "timezone.excity.Antarctica/Macquarie", "\u9ea5\u5938\u91cc" },
            { "timezone.excity.Pacific/Bougainville", "\u5e03\u5e72\u7dad\u723e\u5cf6" },
            { "timezone.excity.America/Indiana/Vevay", "\u5370\u7b2c\u5b89\u7d0d\u5dde\u97cb\u97cb" },
            { "timezone.excity.America/Santo_Domingo", "\u8056\u591a\u660e\u5404" },
            { "timezone.excity.America/St_Barthelemy", "\u8056\u5df4\u6cf0\u52d2\u7c73" },
            { "timezone.excity.America/Bahia_Banderas", "\u5df4\u4f0a\u4e9e\u5fb7\u73ed\u5fb7\u62c9\u65af" },
            { "timezone.excity.America/Indiana/Marengo", "\u5370\u7b2c\u5b89\u7d0d\u5dde\u99ac\u502b\u54e5" },
            { "timezone.excity.America/Indiana/Winamac", "\u5370\u7b2c\u5b89\u7d0d\u5dde\u5a01\u7d0d\u99ac\u514b" },
            { "timezone.excity.America/Indiana/Tell_City", "\u5370\u7b2c\u5b89\u7d0d\u5dde\u7279\u723e\u57ce" },
            { "timezone.excity.America/Indiana/Vincennes", "\u5370\u7b2c\u5b89\u7d0d\u5dde\u6eab\u68ee\u65af" },
            { "timezone.excity.Antarctica/DumontDUrville", "\u675c\u8499\u8fea\u7dad\u723e\u7ad9" },
            { "timezone.excity.America/Argentina/La_Rioja", "\u62c9\u91cc\u5967\u54c8" },
            { "timezone.excity.America/Indiana/Petersburg", "\u5370\u7b2c\u5b89\u7d0d\u5dde\u5f7c\u5f97\u5821" },
            { "timezone.excity.America/North_Dakota/Beulah", "\u5317\u9054\u79d1\u4ed6\u5dde\u6bd4\u5c24\u62c9" },
            { "timezone.excity.America/North_Dakota/Center", "\u5317\u9054\u79d1\u4ed6\u5dde\u4e2d\u5fc3\u5e02" },
            { "timezone.excity.America/North_Dakota/New_Salem", "\u5317\u9054\u79d1\u4ed6\u5dde\u65b0\u85a9\u52d2\u59c6" },
        };
        return data;
    }
}
